#!/usr/bin/env bash
# SPDX-FileCopyrightText: 2024 JayVii <jayvii[AT]posteo[DOT]de>
# SPDX-License-Identifier: GPL-3.0-or-later

# Config -----------------------------------------------------------------------
## Where is your notes folder?
NOTES_DIR="$HOME/Notes"
## Default category for your notes (sub-folder in $NOTES_DIR)
DEFAULT_CATEGORY="Work"
## Your Editor of choice (uses fallback, if $EDITOR is unset)
if [ -z "$EDITOR" ]; then
    EDITOR="vi"
fi

# List all Notes files ---------------------------------------------------------

## List all present notes (remove full path from display)
FILES=$(
    find "${NOTES_DIR}" -type f | \
    sed -e "s#${NOTES_DIR}/##g"
)

## Add today's date as empty file
FILES=$(
    printf "${DEFAULT_CATEGORY}/$(date +%Y_%m_%d).md\n${FILES}" | \
    sort --reverse | \
    uniq
)

# Select Notes file ------------------------------------------------------------
CHOOSEN=$(
	echo "$FILES" | \
	fzf \
	--preview="if [ -f ${NOTES_DIR}/{} ]; then cat ${NOTES_DIR}/{}; fi" \
	--layout=reverse \
	--query="${DEFAULT_CATEGORY}"
)

# Open Notes file --------------------------------------------------------------
if [ ! -z "$CHOOSEN" ]; then
	${EDITOR} "${NOTES_DIR}/${CHOOSEN}"
fi

# EOF notes.sh
